==> mythstream_0.17.2.orig.tar.gz: mythstream-0.17.2.orig/misc/streamtuned.php <==
<?php

// simple authorization check
if ($pass != 'fjkgqajk9fkj')
{
  print "login failed $pass";
  return;
}
// $login not used

include("base.php");

/* Input:
  command
  val0
  val1
  val2
  val3
  oldval0
  oldval1
  oldval2
  oldval3
*/


$folder  = $val0;
$name    = $val1;
$url     = $val2;
$descr   = $val3;
$handler = $val4;

$oldfolder = $oldval0;
$oldname   = $oldval1;
$oldurl    = $oldval2;
$olddescr  = $oldval3;
$oldhandler  = $oldval4;


function check_exist($folder, $name)
{
   global $db, $table;
   $cnt = $db->set_recordset($table, "folder='$folder' and name='$name'");
   if ($cnt > 0)
     return TRUE;
   else
     return FALSE;
}

if ( $command == 'hello')
{
  print "[storage]\n";
  //print "readonly";
  print "writable";
}

if ( $command == 'list')
{
  $cnt = $db->set_recordset($table, "1=1");

  for ($i = 0; $i < $cnt; $i++)
  {
    $folder  = $db->get_recordset_field("folder", $i);
    $name    = $db->get_recordset_field("name"  , $i);
    $url     = $db->get_recordset_field("url"   , $i);
    $descr   = $db->get_recordset_field("description" , $i);
    $handler = $db->get_recordset_field("handler" , $i);
    print "\n[item]\n$folder\n$name\n$url\n$descr\n$handler";
  }
}

if ( $command == 'insert')
{
  if ( !check_exist($folder, $name) )
  {
    $db->queryEX( "insert into $table(folder, name, url, description, handler) values" .
                  "('$folder', '$name', '$url', '$descr', '$handler')" );
    $err = $db->error();
  }
    else $err = "record folder=$folder, name=$name already exists";

  if ( $err != "")
    print $err;
  else
    print "OK";
}

if ( $command == 'update')
{
  if ( check_exist($oldfolder, $oldname) )
  {
    $db->queryEX( "update $table set folder='$folder', name='$name', url='$url', " .
                  "description='$descr', handler='$handler' where folder='$oldfolder' and name='$oldname'" );
    $err = $db->error();
  }
    else $err = "record folder=$oldfolder, name=$oldname not found";

    if ( $err != "" )
      print $err;
    else
      print "OK";
}

if ( $command == 'remove')
{
  if ( check_exist($folder, $name) )
  {
    $db->queryEX( "delete from $table where folder='$folder' and name='$name'" );
    $err = $db->error();
  }
    else $err = "record folder=$folder, name=$name not found";

  if ( $err != "" )
    print $err;
  else
    print "OK";
}

if ( $command == 'savelist')
{
  $res = "NOK";

  if ($count > 0 && $folder[$count-1] != "" )
  {
    $db->queryEX( "delete from $table" );
    $err = $db->error();

    if ( $err == "" )
    {
      for ($i = 0; $i < $count; $i++)
      {
        $query  = "insert into $table(folder, name, url, description, handler) values";
        $query .= "('" . $folder[$i] . "','" . $name[$i] . "','" .  $url[$i];
        $query .= "','" .  $descr[$i] . "','" . $handler[$i] . "')";
        $db->query($query);
        $err .= $db->error();
      }

      if ( $err == "" )
        $res = "OK";
      else
        $res = $err;
    }
  }

  print $res;
}


?>

==> mythstream_0.18.1.orig.tar.gz: mythstream-0.18_1/misc/streamtuned.php <==
<?php

// Warning: totally unsafe. It's a proof of concept.
// Safe implementation requires special chars input check

// simple authorization check
if ($pass != 'fjkgqajk9fkj')
{
  print "login failed $pass";
  return;
}
// $login not used

include("base.php");

/* Input:
  command
  val0
  val1
  val2
  val3
  val4
  oldval0
  oldval1
  oldval2
  oldval3
  oldval4
*/


$folder  = $val0;
$name    = $val1;
$url     = $val2;
$descr   = $val3;
$handler = $val4;

$oldfolder = $oldval0;
$oldname   = $oldval1;
$oldurl    = $oldval2;
$olddescr  = $oldval3;
$oldhandler  = $oldval4;


function check_exist($folder, $name)
{
   global $db, $table;
   $cnt = $db->set_recordset($table, "folder='$folder' and name='$name'");
   if ($cnt > 0)
     return TRUE;
   else
     return FALSE;
}

if ( $command == 'hello')
{
  print "[storage]\n";
  //print "readonly";
  print "writable";
}

if ( $command == 'list')
{
  $cnt = $db->set_recordset($table, "1=1");

  for ($i = 0; $i < $cnt; $i++)
  {
    $folder  = $db->get_recordset_field("folder", $i);
    $name    = $db->get_recordset_field("name"  , $i);
    $url     = $db->get_recordset_field("url"   , $i);
    $descr   = $db->get_recordset_field("description" , $i);
    $handler = $db->get_recordset_field("handler" , $i);

    if ($folder  == "") { $folder  = "[emptystring]"; }
    if ($name    == "") { $name    = "[emptystring]"; }
    if ($url     == "") { $url     = "[emptystring]"; }
    if ($descr   == "") { $descr   = "[emptystring]"; }
    if ($handler == "") { $handler = "[emptystring]"; }
    
    print "\n[item]\n$folder\n$name\n$url\n$descr\n$handler\n";
  }
}

if ( $command == 'insert')
{
  if ( !check_exist($folder, $name) )
  {
    $db->queryEX( "insert into $table(folder, name, url, description, handler) values" .
                  "('$folder', '$name', '$url', '$descr', '$handler')" );
    $err = $db->error();
  }
    else $err = "record folder=$folder, name=$name already exists";

  if ( $err != "")
    print $err;
  else
    print "OK";
}

if ( $command == 'update')
{
  if ( check_exist($oldfolder, $oldname) )
  {
    $db->queryEX( "update $table set folder='$folder', name='$name', url='$url', " .
                  "description='$descr', handler='$handler' where folder='$oldfolder' and name='$oldname'" );
    $err = $db->error();
  }
    else $err = "record folder=$oldfolder, name=$oldname not found";

    if ( $err != "" )
      print $err;
    else
      print "OK";
}

if ( $command == 'remove')
{
  if ( check_exist($folder, $name) )
  {
    $db->queryEX( "delete from $table where folder='$folder' and name='$name'" );
    $err = $db->error();
  }
    else $err = "record folder=$folder, name=$name not found";

  if ( $err != "" )
    print $err;
  else
    print "OK";
}

if ( $command == 'savelist')
{
  $res = "NOK";

  if ($count > 0 && $folder[$count-1] != "" )
  {
    $db->queryEX( "delete from $table" );
    $err = $db->error();

    if ( $err == "" )
    {
      for ($i = 0; $i < $count; $i++)
      {
        $query  = "insert into $table(folder, name, url, description, handler) values";
        $query .= "('" . $folder[$i] . "','" . $name[$i] . "','" .  $url[$i];
        $query .= "','" .  $descr[$i] . "','" . $handler[$i] . "')";
        $db->query($query);
        $err .= $db->error();
      }

      if ( $err == "" )
        $res = "OK";
      else
        $res = $err;
    }
  }

  print $res;
}


?>
